==> pytactoe-0.11.0.tar.gz: pytactoe-0.11.0/README.md <==
# PyTacToe
Simple Python library for classic Tic Tac Toe and its various variants.

## Features

- Default game is (possibly infinite-dimensional) `m,n,k`-game with `p` players: `k`-in-a-row game on an `m`-by-`n` board.
- Move verifying, getting legal moves, checking wins and draws
- Getting move history and reverting moves
- Engine for classic game and variants
- Built-in variants include:
  - Ultimate Tic Tac Toe
  - Misere Tic Tac Toe
  - Impartial Tic Tac Toe
  - Wild Tic Tac Toe


## Installing
Install the latest release using pip:
```
pip install pytactoe
```

## Examples
### Initialize a game and move
```python
from pytactoe import Piece, TicTacToe

newgame = TicTacToe(m=5, n=5, k=3, infinite=False, first_player=Piece(1), players=2)
# 5x5 board, 3 in row to win, non-infinite, "X" (piece 1) moves first, two players

newgame.move(0, 2)    # X moves to (0, 2)
newgame.move(1, 1)    # O moves to (1, 1)
newgame.move(0, 0)    # X moves to (0, 0)
```

### Take a move back and show move history
```python
newgame.pop()
```

```python
print(newgame.move_history)
```
output:
```
[(0, 2), (1, 1)]
```

### Show legal moves on position
```python
print(newgame.legalmoves())
```
output:
```
[(0, 0), (0, 1), (0, 3), (0, 4), (1, 0), (1, 2), (1, 3), (1, 4), (2, 0), (2, 1), (2, 2), (2, 3), (2, 4), (3, 0), (3, 1), (3, 2), (3, 3), (3, 4), (4, 0), (4, 1), (4, 2), (4, 3), (4, 4)]
```

### Show board in ASCII format
```python
print(newgame)
```
output:
```
--X--
-O---
-----
-----
-----
turn: X, ended: False, winned: False, winner: -, draw: False
```

### Play variants
```python
from pytactoe import UltimateTicTacToe, ImpartialTicTacToe, WildTicTacToe, MisereTicTacToe


ult = UltimateTicTacToe(m=3, n=3, k=3, infinite=False, where=(0,0)) # first move on local board (0, 0)
ult.move(1,1) # Playing move (1, 1) on board (0, 0). Changing board to (1, 1)
ult.move(1,2) # Playing move (1, 2) on board (1, 1). Changing board to (1, 2)
ult.move(1,1) # ...

wild = WildTicTacToe() # All games are by default 3x3 with 3-in-a-row
wild.move(0, 1, Piece(2)) # First player place "O" on (0,1)

mis = MisereTicTacToe()

imp = ImpartialTicTacToe()
```

### Use engine
```python
from pytactoe import Engine

newgame = TicTacToe()
resp = Engine.minimax_response(newgame) # Return tuple
newgame.move(*resp)
```

### Simulate a game
```python
newgame = TicTacToe()

while not newgame.ended:
    resp = Engine.random_response(newgame)
    print(f'\nNext move is {resp} by {newgame.turn}')
    print(newgame, '\n')
    newgame.move(*resp)
    print(newgame)
    print('================')
    
print(f'winner: {newgame.winner}, draw: {newgame.draw}\n')
```

## License

PyTacToe is available under the MIT license. For the full text, check out `LICENSE`.

==> pytactoe-0.12.0.tar.gz: pytactoe-0.12.0/README.md <==
# PyTacToe
Simple Python library for classic Tic Tac Toe and its various variants.

## Features

- Default game is (possibly infinite-dimensional) `m,n,k`-game with `p` players: `k`-in-a-row game on an `m`-by-`n` board.
- Move verifying, getting legal moves, checking wins and draws
- Getting move history and reverting moves
- Engine for classic game and variants
- Built-in variants include:
  - Ultimate Tic Tac Toe
  - Misere Tic Tac Toe
  - Impartial Tic Tac Toe
  - Wild Tic Tac Toe


## Installing
Install the latest release using pip:
```
pip install pytactoe
```

## Examples
### Initialize a game and move
```python
from pytactoe import Piece, TicTacToe

newgame = TicTacToe(m=5, n=5, k=3, infinite=False, players=2)
# 5x5 board, 3 in row to win, non-infinite, two players

newgame.move(0, 2)    # X moves to (0, 2)
newgame.move(1, 1)    # O moves to (1, 1)
newgame.move(0, 0)    # X moves to (0, 0)
```

### Take a move back and show move history
```python
newgame.pop()
```

```python
print(newgame.move_history)
```
output:
```
[(0, 2), (1, 1)]
```

### Show legal moves on position
```python
print(newgame.legalmoves())
```
output:
```
[(0, 0), (0, 1), (0, 3), (0, 4), (1, 0), (1, 2), (1, 3), (1, 4), (2, 0), (2, 1), (2, 2), (2, 3), (2, 4), (3, 0), (3, 1), (3, 2), (3, 3), (3, 4), (4, 0), (4, 1), (4, 2), (4, 3), (4, 4)]
```

### Show board in ASCII format
```python
print(newgame)
```
output:
```
--X--
-O---
-----
-----
-----
turn: X, ended: False, winned: False, winner: -, draw: False
```

### Play variants
```python
from pytactoe import UltimateTicTacToe, ImpartialTicTacToe, WildTicTacToe, MisereTicTacToe


ult = UltimateTicTacToe(m=3, n=3, k=3, infinite=False, where=(0,0)) # first move on local board (0, 0)
ult.move(1,1) # Playing move (1, 1) on board (0, 0). Changing board to (1, 1)
ult.move(1,2) # Playing move (1, 2) on board (1, 1). Changing board to (1, 2)
ult.move(1,1) # ...

wild = WildTicTacToe() # All games are by default 3x3 with 3-in-a-row
wild.move(0, 1, Piece(2)) # First player place "O" on (0,1)

mis = MisereTicTacToe()

imp = ImpartialTicTacToe()
```

### Use engine
```python
from pytactoe import Engine

newgame = TicTacToe()
resp = Engine.minimax_response(newgame) # Return tuple
newgame.move(*resp)
```

### Simulate a game
```python
newgame = TicTacToe()

while not newgame.ended:
    resp = Engine.random_response(newgame)
    print(f'\nNext move is {resp} by {newgame.turn}')
    print(newgame, '\n')
    newgame.move(*resp)
    print(newgame)
    print('================')
    
print(f'winner: {newgame.winner}, draw: {newgame.draw}\n')
```

## License

PyTacToe is available under the MIT license. For the full text, check out `LICENSE`.
